/*
 * Copyright (C) 2011 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.chimpchat.core;

import java.awt.image.BufferedImage;

/**
 * ChimpImage interface.
 *
 * This interface defines an image representing a screen snapshot.
 */
public interface IChimpImage {
    // TODO: add java docs
    BufferedImage createBufferedImage();
    BufferedImage getBufferedImage();

    IChimpImage getSubImage(int x, int y, int w, int h);

    byte[] convertToBytes(String format);
    boolean writeToFile(String path, String format);
    int getPixel(int x, int y);
    boolean sameAs(IChimpImage other, double percent);
}
